# Commerce Be2Bill

## Introduction

`commerce_be2bill` implements the payment gateway
[Be2Bill](http://www.be2bill.com/) as a payment method in
[Drupal Commerce](http://drupalcommerce.org).

The 1.x branch is **deprecated** and no longer supported. All
developments occur on 2.x branch or later.

## Features

 + Off site redirection to Be2Bill for entering credit card data.

 + Proper use of SSL/TLS with endpoint validation, something which
   unfortunately is still lacking in many payment methods for Drupal
   Commerce.

 + [Commerce Card On File](https://drupal.org/project/commerce_cardonfile)
   support so that you can re-use client card data in a secure
   manner. No sensitive data is stored on site. It functions via
   token that is associated to a certain card stored on Be2Bill
   servers.

 + **Authorization and Capture** or just **Authorization** and later
   capture offering you greater flexibility as a merchant to bill the
   client just when the products bought are effectively shipped.

 + Refunding of partial or total order values.

## Configuration

After installing the module the configuration is as follows:

 + Login in to your Be2Bill account and configure:

   + The IPN URL of your site, i.e., the URL that Be2Bill will hit in
     your site once a payment is processed. The module uses 
     the Drupal URL `/be2bill/ipn` so on your Be2Bill account
     configuration dashboard you must enter:
     
        http://example.com/be2bill/ipn

     or if your site runs over HTTPS (**recommended**):
     
        https://example.com/be2bill/ipn

     Replace `example.com` with your hostname.

   + Configure the return URL, i.e., the URL the client will return to
     once you enter a card number or if using a stored card via
     [Commerce ](https://drupal.org/project/commerce_cardonfile) if
     relying on [3DSecure](https://en.wikipedia.org/wiki/3-D_Secure)
     for additional validation of the payment by the client. The
     module use the Drupal URL `/be2bill/return` which means for you,
     re-using the above example:

        http://example.com/be2bill/return

     or if your site runs over HTTPS (**recommended**):
     
        https://example.com/be2bill/return

     Replace `example.com` with your hostname.

   + Configure the cancel URL, i.e., the URL the client will be
     redirect to if the wrong card data is entered or the 3DSecure
     validation code is incorrect. The module uses the Drupal URL
     `/be2bill/cancel` so in the dashboard you should enter:
     
        http://example.com/be2bill/cancel

     or if your site runs over HTTPS (**recommended**):
     
        https://example.com/be2bill/cancel

     Replace `example.com` with your hostname.

 + On your site configure the module:

   + Enable it at `admin/commerce/config/payment-methods`.

   + Edit the rule installed by the module.

   + Edit the action `Enable payment method: Be2bill`.

   + Enter your Be2Bill account **username** and **password**. 
    
   + Select the options you're interested in.

   + Save.

   + Done.

In order to use Commerce Card On File to store credit cards on Be2Bill
site for later reuse you **must** install and enable the
[Commerce Card On File](https://drupal.org/projects/commerce_cardonfile)
module. Note that by **default** if the Commerce Card On File module
is installed this option is **enabled**. If that's not the desired
situation uncheck the box.

## Usage

Now you can start charging your clients using Be2Bill as the payment
gateway. All the payment details for each order are at:
`/admin/commerce/orders/<orderID>/payment` where `<orderID>` is the ID
of the order as generated by Drupal Commerce.

There show the the operations that are possible for each payment
transaction relative to that order.

### Authorization and Capture

If you chose `Authorization and Capture` then the total amount of the
order is captured from the client account and it will be transfered to
your account after the normal bank transfer delays.

### Authorization Only

In this case you get an authorization so that later you can capture de
authorized value. Please note that currently it's not possible to do
**multiple captures** after an authorization. So be sure to capture
the totality of the value you want after an authorization.

### Refunds

There's a link for refunding next to each payment transaction. You can
refund as much as you want and as many times as possible given the
total captured amount.

## Recommendations

Although this an offsite payment method, i.e., the card details are
always filled on the Be2Bill site it's strongly recommended to make
the payment process over HTTPS so that a
[Man in the Middle](https://en.wikipedia.org/wiki/Man-in-the-middle_attack)
(MitM) becomes much more difficult than if using HTTP for the payment
process.

## Sponsoring

The module is developed and supported by
[Commerce Guys](https://commerceguys.com) with partial sponsoring of
[Be2Bill](http://www.be2bill.com).
